.. _credits:
.. index:: Credits

.. |br| raw:: html

  <br/>


Credits
*******

:program:`calorine` is primarily developed at the `Department of Physics <https://www.chalmers.se/en/departments/physics/Pages/default.aspx>`_ of `Chalmers University of Technology <https://www.chalmers.se/>`_ in Gothenburg, Sweden with funding from the Knut och Alice Wallenbergs Foundation, the Swedish Research Council, and the Swedish Foundation for Strategic Research, as well as computational support from the National Academic Infrastructure for Supercomputing in Sweden.
         
When using :program:`calorine` in your research, including packages that you build on top of it, please cite the following papers.

* *calorine: A Python package for constructing and sampling neuroevolution potential models* |br|
  Lindgren *et al.*,
  Journal of Open Source Software **9(95)**, 6264 (2024) |br|
  `doi: 10.21105/joss.06264  <https://doi.org/10.21105/joss.06264>`_ |br|
* *GPUMD: A package for constructing accurate machine-learned potentials and performing highly efficient atomistic simulations* |br|
  Fan *et al.*,
  Journal of Chemical Physics **157**, 114801 (2022) |br|
  `doi: 10.1063/5.0106617  <https://doi.org/10.1063/5.0106617>`_ |br|

:program:`calorine` is based on Python3 and invokes functionality from the Python libraries listed below.
To support the development of free-and-open-source-software, please make sure to give proper credit to these packages when citing :program:`calorine` as well.

* `ase <https://wiki.fysik.dtu.dk/ase>`_
* `Matplotlib <https://matplotlib.org/>`_
* `NumPy <https://www.numpy.org/>`_
* `pandas <https://pandas.pydata.org/>`_
* `scikit-learn <https://scikit-learn.org/>`_
* `spglib <https://spglib.readthedocs.io/>`_
